public inbox for ipfire-scm@lists.ipfire.org
 help / color / mirror / Atom feed
From: git@ipfire.org
To: ipfire-scm@lists.ipfire.org
Subject: [git.ipfire.org] IPFire 2.x development tree branch, master, updated. e21cef27840dbca07a4fea3e677ab422c4a90b45
Date: Fri, 30 Jan 2015 00:10:22 +0100	[thread overview]
Message-ID: <20150129231022.64E5521829@argus.ipfire.org> (raw)

[-- Attachment #1: Type: text/plain, Size: 14534 bytes --]

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "IPFire 2.x development tree".

The branch, master has been updated
       via  e21cef27840dbca07a4fea3e677ab422c4a90b45 (commit)
       via  8d903f6db9a2c942d523a9a376d29f8800800639 (commit)
       via  026413980f8baf88787e33b938592b1533d16812 (commit)
       via  40a8ea817a29e83d88a2e8c608dd0b87fb350913 (commit)
      from  4165a41e84fd426e8ee58999fbef1af56d544302 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit e21cef27840dbca07a4fea3e677ab422c4a90b45
Author: Arne Fitzenreiter <arne_f(a)ipfire.org>
Date:   Fri Jan 30 00:09:00 2015 +0100

    kernel: update banana pi, lamobo-r1 and add banana pro dtb.

commit 8d903f6db9a2c942d523a9a376d29f8800800639
Author: Arne Fitzenreiter <arne_f(a)ipfire.org>
Date:   Thu Jan 29 19:00:13 2015 +0100

    core87: work arround u-boot folder detection bug.
    
    some u-boot version seems only scan the first directory entries for
    folders and not find the dtb's if the folder are created to late.

commit 026413980f8baf88787e33b938592b1533d16812
Author: Arne Fitzenreiter <arne_f(a)ipfire.org>
Date:   Thu Jan 29 08:37:59 2015 +0100

    core87: remove linux-xen code from updater.

commit 40a8ea817a29e83d88a2e8c608dd0b87fb350913
Author: Arne Fitzenreiter <arne_f(a)ipfire.org>
Date:   Thu Jan 29 08:36:26 2015 +0100

    core87: remove old dtb's and backup uEnv.txt at update.

-----------------------------------------------------------------------

Summary of changes:
 config/rootfiles/common/armv5tel/linux-multi     |   1 +
 config/rootfiles/core/86/update.sh               |  28 ++-
 lfs/linux                                        |   3 +
 src/patches/linux-3.14.x-update_banana_dts.patch | 301 +++++++++++++++++++++++
 4 files changed, 320 insertions(+), 13 deletions(-)
 create mode 100644 src/patches/linux-3.14.x-update_banana_dts.patch

Difference in files:
diff --git a/config/rootfiles/common/armv5tel/linux-multi b/config/rootfiles/common/armv5tel/linux-multi
index 3ef35e0..63881cd 100644
--- a/config/rootfiles/common/armv5tel/linux-multi
+++ b/config/rootfiles/common/armv5tel/linux-multi
@@ -110,6 +110,7 @@ boot/dtb-KVER-ipfire-multi
 #boot/dtb-KVER-ipfire-multi/sun5i-a13-olinuxino.dtb
 #boot/dtb-KVER-ipfire-multi/sun6i-a31-colombus.dtb
 #boot/dtb-KVER-ipfire-multi/sun7i-a20-bananapi.dtb
+#boot/dtb-KVER-ipfire-multi/sun7i-a20-bananapro.dtb
 #boot/dtb-KVER-ipfire-multi/sun7i-a20-cubieboard2.dtb
 #boot/dtb-KVER-ipfire-multi/sun7i-a20-cubietruck.dtb
 #boot/dtb-KVER-ipfire-multi/sun7i-a20-lamobo-r1.dtb
diff --git a/lfs/linux b/lfs/linux
index 8295c4b..f961340 100644
--- a/lfs/linux
+++ b/lfs/linux
@@ -172,6 +172,9 @@ ifeq "$(KCFG)" "-multi"
 	# Apply Arm7-multiarch kernel patches.
 	cd $(DIR_APP) && xzcat $(DIR_DL)/arm7-multi-patches-$(A7M_PATCHES).patch.xz | patch -Np1
 
+	# Update Banana Pi, Lamobo-R1 and add Banana Pro dtb
+	cd $(DIR_APP) && patch -Np1 < $(DIR_SRC)/src/patches/linux-3.14.x-update_banana_dts.patch
+
 	# Install switch api userspace header
 	cd $(DIR_APP) && install -v -m644 include/uapi/linux/switch.h /usr/include/linux/
 endif
diff --git a/src/patches/linux-3.14.x-update_banana_dts.patch b/src/patches/linux-3.14.x-update_banana_dts.patch
new file mode 100644
index 0000000..309416b
--- /dev/null
+++ b/src/patches/linux-3.14.x-update_banana_dts.patch
@@ -0,0 +1,301 @@
+diff -Naur linux-3.14.30.org/arch/arm/boot/dts/Makefile linux-3.14.30/arch/arm/boot/dts/Makefile
+--- linux-3.14.30.org/arch/arm/boot/dts/Makefile	2015-01-29 19:56:17.000000000 +0100
++++ linux-3.14.30/arch/arm/boot/dts/Makefile	2015-01-29 20:41:06.598335182 +0100
+@@ -304,6 +304,7 @@
+ 	sun5i-a13-olinuxino-micro.dtb \
+ 	sun6i-a31-colombus.dtb \
+ 	sun7i-a20-bananapi.dtb \
++	sun7i-a20-bananapro.dtb \
+ 	sun7i-a20-cubieboard2.dtb \
+ 	sun7i-a20-cubietruck.dtb \
+ 	sun7i-a20-lamobo-r1.dtb \
+diff -Naur linux-3.14.30.org/arch/arm/boot/dts/sun7i-a20-bananapi.dts linux-3.14.30/arch/arm/boot/dts/sun7i-a20-bananapi.dts
+--- linux-3.14.30.org/arch/arm/boot/dts/sun7i-a20-bananapi.dts	2015-01-29 19:56:17.000000000 +0100
++++ linux-3.14.30/arch/arm/boot/dts/sun7i-a20-bananapi.dts	2015-01-29 20:33:18.143334959 +0100
+@@ -199,7 +199,7 @@
+ 			regulator-name = "gmac-3v3";
+ 			regulator-min-microvolt = <3300000>;
+ 			regulator-max-microvolt = <3300000>;
+-			startup-delay-us = <50000>;
++			startup-delay-us = <100000>;
+ 			enable-active-high;
+ 			gpio = <&pio 7 23 0>;
+ 			status = "okay";
+diff -Naur linux-3.14.30.org/arch/arm/boot/dts/sun7i-a20-bananapro.dts linux-3.14.30/arch/arm/boot/dts/sun7i-a20-bananapro.dts
+--- linux-3.14.30.org/arch/arm/boot/dts/sun7i-a20-bananapro.dts	1970-01-01 01:00:00.000000000 +0100
++++ linux-3.14.30/arch/arm/boot/dts/sun7i-a20-bananapro.dts	2015-01-29 20:40:45.153335172 +0100
+@@ -0,0 +1,262 @@
++/*
++ * Copyright 2015 Arne Fitzenreiter
++ * Arne Fitzenreiter <arne_f(a)ipfire.org>
++ *
++ * The code contained herein is licensed under the GNU General Public
++ * License. You may obtain a copy of the GNU General Public License
++ * Version 2 or later at the following locations:
++ *
++ * http://www.opensource.org/licenses/gpl-license.html
++ * http://www.gnu.org/copyleft/gpl.html
++ */
++
++/dts-v1/;
++/include/ "sun7i-a20.dtsi"
++/include/ "sunxi-common-regulators.dtsi"
++#include <dt-bindings/input/input.h>
++
++/ {
++	model = "LeMaker Banana Pro";
++	compatible = "lemaker,bananapro", "allwinner,sun7i-a20";
++
++	aliases {
++		spi0 = &spi1;
++		spi1 = &spi2;
++	};
++
++	soc(a)01c00000 {
++		spi1: spi(a)01c06000 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&spi1_pins_a>;
++			status = "okay";
++		};
++
++		spi2: spi(a)01c17000 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&spi2_pins_a>;
++			status = "okay";
++		};
++
++		mmc0: mmc(a)01c0f000 {
++			pinctrl-names = "default", "default";
++			pinctrl-0 = <&mmc0_pins_a>;
++			pinctrl-1 = <&mmc0_cd_pin_bananapi>;
++			cd-gpios = <&pio 7 10 0>; /* PH10 */
++			status = "okay";
++		};
++
++		mmc3: mmc(a)01c12000 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&mmc3_pins_a>;
++			vmmc-supply = <&reg_vmmc3>;
++			bus-width = <4>;
++			non-removable;
++			status = "okay";
++		};
++
++		usbphy: phy(a)01c13400 {
++			usb1_vbus-supply = <&reg_usb1_vbus>;
++			usb2_vbus-supply = <&reg_usb2_vbus>;
++			status = "okay";
++		};
++
++		ehci0: usb(a)01c14000 {
++			status = "okay";
++		};
++
++		ohci0: usb(a)01c14400 {
++			status = "okay";
++		};
++
++		ahci: sata(a)01c18000 {
++			target-supply = <&reg_ahci_5v>;
++			status = "okay";
++		};
++
++		ehci1: usb(a)01c1c000 {
++			status = "okay";
++		};
++
++		ohci1: usb(a)01c1c400 {
++			status = "okay";
++		};
++
++		pinctrl(a)01c20800 {
++			usb1_vbus_pin_bananapro: usb1_vbus_pin(a)0 {
++				allwinner,pins = "PH0";
++				allwinner,function = "gpio_out";
++				allwinner,drive = <0>;
++				allwinner,pull = <0>;
++			};
++
++			usb2_vbus_pin_bananapro: usb2_vbus_pin(a)0 {
++				allwinner,pins = "PH1";
++				allwinner,function = "gpio_out";
++				allwinner,drive = <0>;
++				allwinner,pull = <0>;
++			};
++
++			led_pins_bananapi: led_pins(a)0 {
++				allwinner,pins = "PH24", "PG2";
++				allwinner,function = "gpio_out";
++				allwinner,drive = <0>;
++				allwinner,pull = <0>;
++			};
++
++			mmc0_cd_pin_bananapi: mmc0_cd_pin(a)0 {
++				allwinner,pins = "PH10";
++				allwinner,function = "gpio_in";
++				allwinner,drive = <0>;
++				allwinner,pull = <1>;
++			};
++ 
++			vmmc3_pin_bananapro: vmmc3_pin(a)0 {
++				allwinner,pins = "PH22";
++				allwinner,function = "gpio_out";
++				allwinner,drive = <0>;
++				allwinner,pull = <0>;
++			};
++
++			gmac_power_pin_bananapi: gmac_power_pin(a)0 {
++				allwinner,pins = "PH23";
++				allwinner,function = "gpio_out";
++				allwinner,drive = <0>;
++				allwinner,pull = <0>;
++			};
++		};
++
++		lradc: lradc(a)01c22800 {
++			allwinner,chan0-step = <200>;
++			linux,chan0-keycodes = <KEY_VOLUMEUP KEY_VOLUMEDOWN
++						KEY_MENU KEY_SEARCH KEY_HOME
++						KEY_ESC KEY_ENTER>;
++			status = "okay";
++		};
++
++		ir0: ir(a)01c21800 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&ir0_pins_a>;
++			status = "okay";
++		};
++
++		uart0: serial(a)01c28000 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&uart0_pins_a>;
++			status = "okay";
++		};
++
++		uart2: serial(a)01c28800 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&uart2_pins_a>;
++			status = "okay";
++		};
++
++		uart6: serial(a)01c29800 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&uart6_pins_a>;
++			status = "okay";
++		};
++
++		uart7: serial(a)01c29c00 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&uart7_pins_a>;
++			status = "okay";
++		};
++
++		i2c0: i2c(a)01c2ac00 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&i2c0_pins_a>;
++			status = "okay";
++
++			axp: axp20x(a)34 {
++				reg = <0x34>;
++				interrupt-parent = <&nmi_intc>;
++				interrupts = <0 8>;
++				axp,system-power-controller;
++				/include/ "x-powers-axp209.dtsi"
++			};
++		};
++
++		i2c1: i2c(a)01c2b000 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&i2c1_pins_a>;
++			status = "okay";
++		};
++
++		i2c2: i2c(a)01c2b400 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&i2c2_pins_a>;
++			status = "okay";
++		};
++
++		gmac: ethernet(a)01c50000 {
++			pinctrl-names = "default";
++			pinctrl-0 = <&gmac_pins_rgmii_a>;
++			phy = <&phy1>;
++			phy-mode = "rgmii";
++			phy-supply = <&reg_gmac_3v3>;
++			status = "okay";
++
++			phy1: ethernet-phy(a)1 {
++				reg = <1>;
++			};
++		};
++	};
++
++	leds {
++		compatible = "gpio-leds";
++		pinctrl-names = "default";
++		pinctrl-0 = <&led_pins_bananapi>;
++
++		green {
++			label = "bananapi:green:usr";
++			gpios = <&pio 7 24 0>;
++			linux,default-trigger = "heartbeat";
++		};
++		blue {
++			label = "bananapi:blue:usr";
++			gpios = <&pio 6 2 0>;
++			linux,default-trigger = "mmc0";
++		};
++	};
++
++        reg_ahci_5v: ahci-5v {
++                status = "okay";
++        };
++
++        reg_usb1_vbus: usb1-vbus {
++		pinctrl-0 = <&usb1_vbus_pin_bananapro>;
++		gpio = <&pio 7 0 0>; /* PH0 */
++                status = "okay";
++        };
++
++        reg_usb2_vbus: usb2-vbus {
++		pinctrl-0 = <&usb2_vbus_pin_bananapro>;
++		gpio = <&pio 7 1 0>; /* PH1 */
++                status = "okay";
++        };
++
++	reg_gmac_3v3: gmac-3v3 {
++			compatible = "regulator-fixed";
++			pinctrl-names = "default";
++			pinctrl-0 = <&gmac_power_pin_bananapi>;
++			regulator-name = "gmac-3v3";
++			regulator-min-microvolt = <3300000>;
++			regulator-max-microvolt = <3300000>;
++			startup-delay-us = <100000>;
++			enable-active-high;
++			gpio = <&pio 7 23 0>;
++			status = "okay";
++	};
++
++	reg_vmmc3: vmmc3 {
++		compatible = "regulator-fixed";
++		pinctrl-names = "default";
++		pinctrl-0 = <&vmmc3_pin_bananapro>;
++		regulator-name = "vmmc3";
++		regulator-min-microvolt = <3300000>;
++		regulator-max-microvolt = <3300000>;
++		enable-active-high;
++		gpio = <&pio 7 22 0>;
++	};
++};
+diff -Naur linux-3.14.30.org/arch/arm/boot/dts/sun7i-a20-lamobo-r1.dts linux-3.14.30/arch/arm/boot/dts/sun7i-a20-lamobo-r1.dts
+--- linux-3.14.30.org/arch/arm/boot/dts/sun7i-a20-lamobo-r1.dts	2015-01-29 19:56:17.000000000 +0100
++++ linux-3.14.30/arch/arm/boot/dts/sun7i-a20-lamobo-r1.dts	2015-01-30 00:00:01.678340873 +0100
+@@ -199,7 +199,7 @@
+ 			regulator-name = "gmac-3v3";
+ 			regulator-min-microvolt = <3300000>;
+ 			regulator-max-microvolt = <3300000>;
+-			startup-delay-us = <50000>;
++			startup-delay-us = <100000>;
+ 			enable-active-high;
+ 			gpio = <&pio 7 23 0>;
+ 			status = "okay";


hooks/post-receive
diff --git a/config/rootfiles/core/86/update.sh b/config/rootfiles/core/86/update.sh
index bb7453f..8a820e2 100644
--- a/config/rootfiles/core/86/update.sh
+++ b/config/rootfiles/core/86/update.sh
@@ -69,7 +69,7 @@ fi
 echo
 echo Update Kernel to $KVER ...
 #
 # Remove old kernel, configs, initrd, modules ...
 #
 rm -rf /boot/System.map-*
 rm -rf /boot/config-*
@@ -78,6 +78,7 @@ rm -rf /boot/initramfs-*
 rm -rf /boot/vmlinuz-*
 rm -rf /boot/uImage-ipfire-*
 rm -rf /boot/uInit-ipfire-*
+rm -rf /boot/dtb-*-ipfire-*
 rm -rf /lib/modules
 
 case "$(uname -m)" in
@@ -88,7 +89,18 @@ case "$(uname -m)" in
 		# Remove all files that belong to GRUB-legacy
 		rm -rfv /boot/grub
 		;;
+	armv*)
+		# Backup uEnv.txt if exist
+		if [ -e /boot/uEnv.txt ]; then
+			cp -vf /boot/uEnv.txt /boot/uEnv.txt.org
+		fi
+
+		# work around the u-boot folder detection bug
+		mkdir -pv /boot/dtb-$KVER-ipfire-kirkwood
+		mkdir -pv /boot/dtb-$KVER-ipfire-multi
+		;;
 esac
+
 #
 #Stop services
 /etc/init.d/snort stop
@@ -113,6 +125,8 @@ if [ $BOOTSPACE -lt 1000 ]; then
 			# Special handling for old kirkwood images.
 			# (install only kirkwood kernel)
 			rm -rf /boot/*
+			# work around the u-boot folder detection bug
+			mkdir -pv /boot/dtb-$KVER-ipfire-kirkwood
 			tar xavf /opt/pakfire/tmp/files* --no-overwrite-dir -p \
 				--numeric-owner -C / --wildcards 'boot/*-kirkwood*'
 			;;
@@ -180,18 +194,6 @@ if [ ! "$(grep "^flags.* pae " /proc/cpuinfo)" == "" ]; then
 	fi
 fi
 
-# Force reinstall xen kernel if it was installed
-if [ -e "/opt/pakfire/db/installed/meta-linux-xen" ]; then
-	echo "Name: linux-xen" > /opt/pakfire/db/installed/meta-linux-xen
-	echo "ProgVersion: 0" >> /opt/pakfire/db/installed/meta-linux-xen
-	echo "Release: 0"     >> /opt/pakfire/db/installed/meta-linux-xen
-	echo "Name: linux-xen" > /opt/pakfire/db/meta/meta-linux-xen
-	echo "ProgVersion: 0" >> /opt/pakfire/db/meta/meta-linux-xen
-	echo "Release: 0"     >> /opt/pakfire/db/meta/meta-linux-xen
-	# Add xvc0 to /etc/securetty
-	echo "xvc0" >> /etc/securetty
-fi
-
 #
 # After pakfire has ended run it again and update the lists and do upgrade
 #
@@ -69,7 +69,7 @@ fi
 echo Update Kernel to $KVER ...
 #
-# Remove old kernel, configs, initrd, modules ...
+# Remove old kernel, configs, initrd, modules, dtb's ...
 #
 rm -rf /boot/System.map-*
--
IPFire 2.x development tree

                 reply	other threads:[~2015-01-29 23:10 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20150129231022.64E5521829@argus.ipfire.org \
    --to=git@ipfire.org \
    --cc=ipfire-scm@lists.ipfire.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox